/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'list', 'ar', {
	bulletedlist: 'ادخال/حذف تعداد نقطي',
	numberedlist: 'ادخال/حذف تعداد رقمي'
} );
