/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'list', 'ja', {
	bulletedlist: '番号無しリスト',
	numberedlist: '番号付きリスト'
} );
