/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'list', 'bg', {
	bulletedlist: 'Вмъкване/Премахване на точков списък',
	numberedlist: 'Вмъкване/Премахване на номериран списък'
} );
