/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'specialchar', 'nb', {
	options: 'Alternativer for spesialtegn',
	title: 'Velg spesialtegn',
	toolbar: 'Sett inn spesialtegn'
} );
