/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'stylescombo', 'ar', {
	label: 'أنماط',
	panelTitle: 'أنماط التنسيق',
	panelTitle1: 'أنماط الفقرة',
	panelTitle2: 'أنماط مضمنة',
	panelTitle3: 'أنماط الكائن'
} );
